aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorkalyanreddy <reddyx.gundarapu@intel.com>2017-04-17 10:46:23 +0530
committerJing Lu <lvjing5@huawei.com>2017-05-04 12:27:14 +0000
commit857e3393bbd801154f35ddc7109ec8d6009c5b46 (patch)
tree443b27f0937c3041e072bb248200e5b44503ba4f
parent77d38685b12e968147432649d0546eeb97319e39 (diff)
KVMFORNFV:Passing breaktrace option to cyclictest.
This patch is used to add breaktrace option to monitor the latency values while executing cyclictest test cases as a part of kvmfornfv verify and daily jobs. Change-Id: I035ea72a8946a9d3db37a6ee33ffbf3ca67834a2 Signed-off-by: Gundarapu Kalyan Reddy <reddyx.gundarapu@intel.com> (cherry picked from commit 97c39be854022146b1c27fa2932bdc88a8781cf9)
-rw-r--r--yardstick/benchmark/scenarios/compute/cyclictest.py6
1 files changed, 4 insertions, 2 deletions
diff --git a/yardstick/benchmark/scenarios/compute/cyclictest.py b/yardstick/benchmark/scenarios/compute/cyclictest.py
index ae1d37324..9ca3a8a37 100644
--- a/yardstick/benchmark/scenarios/compute/cyclictest.py
+++ b/yardstick/benchmark/scenarios/compute/cyclictest.py
@@ -172,14 +172,15 @@ class Cyclictest(base.Scenario):
options = self.scenario_cfg["options"]
affinity = options.get("affinity", 1)
+ breaktrace = options.get("breaktrace", 1000)
interval = options.get("interval", 1000)
priority = options.get("priority", 99)
loops = options.get("loops", 1000)
threads = options.get("threads", 1)
histogram = options.get("histogram", 90)
- cmd_args = "-a %s -i %s -p %s -l %s -t %s -h %s %s" \
- % (affinity, interval, priority, loops,
+ cmd_args = "-a %s -b %s -i %s -p %s -l %s -t %s -h %s %s" \
+ % (affinity, breaktrace, interval, priority, loops,
threads, histogram, default_args)
cmd = "bash cyclictest_benchmark.sh %s" % (cmd_args)
LOG.debug("Executing command: %s", cmd)
@@ -221,6 +222,7 @@ def _test(): # pragma: no cover
options = {
"affinity": 2,
+ "breaktrace": 1000,
"interval": 100,
"priority": 88,
"loops": 10000,